Timestamp

Struct Timestamp 

pub struct Timestamp(/* private fields */);
Timestamp contains the date time in an easy-to-read format.

Implementations

Source

impl Timestamp

pub fn new(dt: DateTime<Local>) -> Self

Create a Timestamp from a local DateTime<Local>.

pub fn pending() -> (String, String)

Create a Timestamp with date and time set as pending ("-").

pub fn as_local(&self) -> DateTime<Local>

Tries to convert the Timestamp into a DateTime<Local>.

Parses the stored date and time strings using the format M/D/YY H:MM AM/PM.

pub fn friendly(&self) -> String

Returns a human-readable, “direct” representation of the timestamp.

Formats the timestamp based on how recent it is:

  • Today: "H:MM am/pm"
  • Yesterday: "yesterday, H:MM am/pm"
  • Same week: day of the week (e.g., "Monday")
  • Same year: "Month D" (e.g., "August 16")
  • Otherwise: "MM/DD/YY"

Returns None if the timestamp cannot be converted to a local datetime.

pub fn date_friendly(&self) -> String

pub fn date(&self) -> String

Returns the date.

pub fn time(&self) -> String

Returns the time.