Trait Callback
Source pub trait Callback: FnMut(&mut Context) + 'static {
// Required method
fn clone_box(&self) -> Box<dyn Callback>;
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.